pub enum FunctionArgumentClause {
IgnoreOrRespectNulls(NullTreatment),
Where(Expr),
OrderBy(Vec<OrderByExpr>),
Limit(Expr),
OnOverflow(ListAggOnOverflow),
Having(HavingBound),
Separator(ValueWithSpan),
JsonNullClause(JsonNullClause),
JsonReturningClause(JsonReturningClause),
}Expand description
Clauses that can appear inside a function argument list.
Variants
IgnoreOrRespectNulls(NullTreatment)
Indicates how NULLs should be handled in the calculation, e.g. in FIRST_VALUE on BigQuery.
Syntax:
{ IGNORE | RESPECT } NULLS ]Where(Expr)
The inline WHERE filter clause on an aggregate call, e.g.
COUNT(* WHERE cond) / SUM(x WHERE cond) / ARRAY_AGG(x WHERE cond ORDER BY ..).
Popularized by GoogleSQL; equivalent to the standard AGG(x) FILTER (WHERE cond).
Accepted for all dialects since WHERE cannot otherwise begin a function argument.
OrderBy(Vec<OrderByExpr>)
Specifies the the ordering for some ordered set aggregates, e.g. ARRAY_AGG on BigQuery.
Limit(Expr)
Specifies a limit for the ARRAY_AGG and ARRAY_CONCAT_AGG functions on BigQuery.
OnOverflow(ListAggOnOverflow)
Specifies the behavior on overflow of the LISTAGG function.
Having(HavingBound)
Specifies a minimum or maximum bound on the input to ANY_VALUE on BigQuery.
Syntax:
HAVING { MAX | MIN } expressionSeparator(ValueWithSpan)
The SEPARATOR clause to the GROUP_CONCAT function in MySQL.
JsonNullClause(JsonNullClause)
The ON NULL clause for some JSON functions.
MSSQL JSON_ARRAY
MSSQL JSON_OBJECT
PostgreSQL JSON functions
JsonReturningClause(JsonReturningClause)
The RETURNING clause for some JSON functions in PostgreSQL